@@ -9,47 +9,23 @@ Transcript 解析工具模块
 - 提取使用的工具列表
 - 统计消息数量
 - 读取完整内容
+- 压缩 transcript 内容
 """
 
 import json
 import logging
-from typing import Optional, Dict, List
+import gzip
+import base64
+from typing import Optional, Dict, List, Any
 from datetime import datetime, timezone, timedelta
-from pathlib import Path
 
-from devlake_mcp.constants import HOOK_LOG_DIR
+from devlake_mcp.constants import (
+    TRANSCRIPT_COMPRESSION_THRESHOLD,
+    TRANSCRIPT_COMPRESSION_ALGORITHM,
+)
 
-# 配置日志
-log_dir = Path(HOOK_LOG_DIR)
-log_dir.mkdir(parents=True, exist_ok=True)
-
-# 创建当前模块的 logger（不使用 basicConfig 避免污染全局配置）
+# 配置日志（使用标准 Python logging）
 logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
-
-# 避免日志重复（如果 logger 已有 handlers，不再添加）
-if not logger.handlers:
-    # 创建文件 handler
-    file_handler = logging.FileHandler(log_dir / 'transcript_utils.log')
-    file_handler.setLevel(logging.DEBUG)
-
-    # 创建控制台 handler
-    console_handler = logging.StreamHandler()
-    console_handler.setLevel(logging.DEBUG)
-
-    # 设置日志格式
-    formatter = logging.Formatter('%(asctime)s [%(levelname)s] %(name)s: %(message)s')
-    file_handler.setFormatter(formatter)
-    console_handler.setFormatter(formatter)
-
-    # 添加 handlers 到 logger
-    logger.addHandler(file_handler)
-    logger.addHandler(console_handler)
-
-# 抑制第三方库的 DEBUG 日志（避免捕获 urllib3、requests 等的日志）
-logging.getLogger('urllib3').setLevel(logging.WARNING)
-logging.getLogger('urllib3.connectionpool').setLevel(logging.WARNING)
-logging.getLogger('requests').setLevel(logging.WARNING)
 
 # 时区配置
 UTC_PLUS_8 = timezone(timedelta(hours=8))
@@ -475,3 +451,97 @@ def get_transcript_stats(transcript_path: str) -> Dict:
             'file_size_bytes': 0,
             'file_size_kb': 0.0
         }
+
+
+def compress_transcript_content(
+    content: str,
+    threshold_bytes: int = TRANSCRIPT_COMPRESSION_THRESHOLD
+) -> Dict[str, Any]:
+    """
+    智能压缩 transcript 内容
+
+    根据内容大小自动判断是否需要压缩：
+    - 大于阈值：使用 gzip 压缩 + base64 编码
+    - 小于阈值：直接返回原始内容
+
+    Args:
+        content: 原始 JSONL 内容（字符串）
+        threshold_bytes: 压缩阈值（字节），默认使用 TRANSCRIPT_COMPRESSION_THRESHOLD
+
+    Returns:
+        Dict[str, Any]: {
+            'content': str,           # 处理后的内容（压缩+base64 或原始）
+            'compression': str,        # 压缩类型：'gzip' 或 'none'
+            'original_size': int,      # 原始大小（字节）
+            'compressed_size': int,    # 处理后大小（字节）
+            'compression_ratio': float # 压缩率（百分比，0-100）
+        }
+
+    异常处理：
+        如果压缩过程失败，会自动降级为不压缩，返回原始内容。
+
+    示例：
+        >>> content = read_transcript_content('/path/to/transcript.jsonl')
+        >>> result = compress_transcript_content(content)
+        >>> if result['compression'] == 'gzip':
+        >>>     logger.info(f"压缩率: {result['compression_ratio']:.1f}%")
+    """
+    try:
+        # 1. 计算原始大小
+        content_bytes = content.encode('utf-8')
+        original_size = len(content_bytes)
+
+        # 2. 判断是否需要压缩
+        if original_size <= threshold_bytes:
+            # 不压缩，直接返回原始内容
+            logger.debug(
+                f"Transcript 大小 {original_size} bytes <= {threshold_bytes} bytes，不压缩"
+            )
+            return {
+                'content': content,
+                'compression': 'none',
+                'original_size': original_size,
+                'compressed_size': original_size,
+                'compression_ratio': 0.0
+            }
+
+        # 3. 执行压缩
+        logger.debug(
+            f"Transcript 大小 {original_size} bytes > {threshold_bytes} bytes，开始压缩"
+        )
+
+        # gzip 压缩
+        compressed_bytes = gzip.compress(content_bytes, compresslevel=6)
+        compressed_size = len(compressed_bytes)
+
+        # base64 编码（以便在 JSON 中传输）
+        encoded_content = base64.b64encode(compressed_bytes).decode('ascii')
+
+        # 4. 计算压缩率
+        compression_ratio = (1 - compressed_size / original_size) * 100
+
+        logger.info(
+            f"压缩完成：{original_size} bytes → {compressed_size} bytes "
+            f"(压缩率: {compression_ratio:.1f}%)"
+        )
+
+        return {
+            'content': encoded_content,
+            'compression': TRANSCRIPT_COMPRESSION_ALGORITHM,
+            'original_size': original_size,
+            'compressed_size': compressed_size,
+            'compression_ratio': round(compression_ratio, 2)
+        }
+
+    except Exception as e:
+        # 压缩失败，降级为不压缩
+        logger.error(f"压缩 transcript 失败，使用原始内容: {e}", exc_info=True)
+
+        original_size = len(content.encode('utf-8'))
+        return {
+            'content': content,
+            'compression': 'none',
+            'original_size': original_size,
+            'compressed_size': original_size,
+            'compression_ratio': 0.0
+        }
