@@ -80,7 +80,7 @@ from pathlib import Path
 from fastmcp import FastMCP
 
 from .client import DevLakeClient
-from .git_utils import get_git_info, get_git_repo_path, get_git_root
+from .git_utils import get_git_info, get_git_repo_path, get_git_root, get_full_git_context
 from .utils import (
     get_temp_file_path,
     compress_content,
@@ -147,9 +147,9 @@ def record_session_impl(
             'git_email': git_email
         }
 
-        # 7. 调用 DevLake API 创建会话
-        client = DevLakeClient()
-        response = client.post('/api/ai-coding/sessions', session_data)
+        # 7. 调用 DevLake API 创建会话（使用 context manager）
+        with DevLakeClient() as client:
+            response = client.post('/api/ai-coding/sessions', session_data)
 
         # 8. 返回结果
         return {
@@ -308,25 +308,15 @@ def after_edit_file_impl(
         changes = []
         cwd = os.getcwd()
 
-        # ====================================================================
-        # Git 信息获取策略：
-        # - 静态信息（author, email, repo_path）：从环境变量读取（初始化时已设置）
-        # - 动态信息（branch, commit）：每次执行 git 命令获取最新值
-        # ====================================================================
-
-        # 1. 静态信息：从环境变量读取（避免重复执行 git config）
-        git_author = os.getenv('GIT_AUTHOR', 'unknown')
-        git_email = os.getenv('GIT_EMAIL', 'unknown')
-        git_repo_path = os.getenv('GIT_REPO_PATH', 'unknown')
-
-        # 2. 动态信息：每次获取最新值（确保 branch/commit 正确）
-        git_info = get_git_info(cwd, include_user_info=False)
-        git_branch = git_info.get('git_branch', 'unknown')
-        git_commit = git_info.get('git_commit', 'unknown')
-
-        # 提取 project_name 和 git_root
-        project_name = git_repo_path.split('/')[-1] if '/' in git_repo_path else git_repo_path
-        git_root = get_git_root(cwd)
+        # 获取完整的 Git 上下文（使用统一接口，避免代码重复）
+        git_context = get_full_git_context(cwd, use_env_cache=True)
+        git_author = git_context['git_author']
+        git_email = git_context['git_email']
+        git_repo_path = git_context['git_repo_path']
+        git_branch = git_context['git_branch']
+        git_commit = git_context['git_commit']
+        project_name = git_context['project_name']
+        git_root = git_context['git_root']
 
         # 从 metadata 中获取 ide_type 和 model_name
         metadata = metadata or {}
@@ -403,10 +393,10 @@ def after_edit_file_impl(
                 except Exception:
                     pass
 
-        # 10. 批量上传到 DevLake API
+        # 10. 批量上传到 DevLake API（使用 context manager）
         if changes:
-            client = DevLakeClient()
-            response = client.post('/api/ai-coding/file-changes', {'changes': changes})
+            with DevLakeClient() as client:
+                response = client.post('/api/ai-coding/file-changes', {'changes': changes})
 
         return {
             'success': True,
